==> matrix_api-2.0.1.tar.gz: matrix_api/src/Plugin/Action/SendMessage.php <==
<?php

namespace Drupal\matrix_api\Plugin\Action;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\BubbleableMetadata;
use Drupal\Core\Session\AccountInterface;
use Drupal\eca\Plugin\Action\ConfigurableActionBase;
use Drupal\eca\Plugin\Action\ConfigurableActionTrait;
use Drupal\matrix_api\MatrixClientInterface;

/**
 * Provides a a Send a message to a Matrix room action.
 *
 * @Action(
 *   id = "matrix_api_send_message",
 *   label = @Translation("Send Message"),
 *   description = @Translation("Sends a message to a specified Matrix room."),
 * )
 *
 * @DCG
 * For a simple updating entity fields consider extending FieldUpdateActionBase.
 */
class SendMessage extends ConfigurableActionBase {

  use ConfigurableActionTrait;

  /**
   * {@inheritdoc}
   */
  public function execute(): void {
    /** @var MatrixClientInterface $matrixClient */
    $matrixClient = \Drupal::service('matrix_api.matrix_client');
    $room = $this->tokenServices->replaceClear($this->configuration['room']);
    $roomId = $matrixClient->join($room);
    $message = $this->configuration['message'];
    $context = [];
    // Code borrowed from eca_log
    foreach ($this->tokenServices->scan($message) as $type => $tokens) {
      $replacements = $this->tokenServices->generate($type, $tokens, [], ['clear' => TRUE], new BubbleableMetadata());
      foreach ($replacements as $original_token => $replacement_value) {
        $context_argument = '%token__' . mb_substr(str_replace(':', '_', $original_token), 1, -1);
        $message = str_replace($original_token, $context_argument, $message);
        $context[$context_argument] = $replacement_value;
      }
      $matrixClient->sendMessage($roomId, $this->t($message, $context));
    }
  }

  /**
   * {@inheritDoc}
   */
  public function defaultConfiguration(): array
  {
    return [
      'room' => '',
      'message' => '',
    ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritDoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state): array {
    $form = parent::buildConfigurationForm($form, $form_state);
    $form['room'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Room'),
      '#default_value' => $this->configuration['room'],
      '#description' => $this->t('The Room alias or id to send the message.'),
      '#weight' => -30,
    ];

    $form['message'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Message'),
      '#description' => $this->t('The message to send.'),
      '#default_value' => $this->configuration['message'],
      '#weight' => -10,
    ];

    return $form;
  }

  /**
   * {@inheritDoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state): void {
    $this->configuration['room'] = $form_state->getValue('room');
    $this->configuration['message'] = $form_state->getValue('message');
    parent::submitConfigurationForm($form, $form_state);
  }
}

==> matrix_api-2.0.2.tar.gz: matrix_api/src/Plugin/Action/SendMessage.php <==
<?php

namespace Drupal\matrix_api\Plugin\Action;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\BubbleableMetadata;
use Drupal\Core\Session\AccountInterface;
use Drupal\eca\Plugin\Action\ConfigurableActionBase;
use Drupal\eca\Plugin\Action\ConfigurableActionTrait;
use Drupal\matrix_api\MatrixClientInterface;

/**
 * Provides a a Send a message to a Matrix room action.
 *
 * @Action(
 *   id = "matrix_api_send_message",
 *   label = @Translation("Send Message"),
 *   description = @Translation("Sends a message to a specified Matrix room."),
 * )
 *
 * @DCG
 * For a simple updating entity fields consider extending FieldUpdateActionBase.
 */
class SendMessage extends ConfigurableActionBase {

  use ConfigurableActionTrait;

  /**
   * {@inheritdoc}
   */
  public function execute(): void {
    /** @var MatrixClientInterface $matrixClient */
    $matrixClient = \Drupal::service('matrix_api.matrixclient');
    $room = $this->tokenServices->replaceClear($this->configuration['room']);
    $roomId = $matrixClient->join($room);
    $message = $this->tokenServices->replaceClear($this->configuration['message']);
    $matrixClient->sendMessage($roomId, $message);
  }

  /**
   * {@inheritDoc}
   */
  public function defaultConfiguration(): array
  {
    return [
      'room' => '',
      'message' => '',
    ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritDoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state): array {
    $form = parent::buildConfigurationForm($form, $form_state);
    $form['room'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Room'),
      '#default_value' => $this->configuration['room'],
      '#description' => $this->t('The Room alias or id to send the message.'),
      '#weight' => -30,
    ];

    $form['message'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Message'),
      '#description' => $this->t('The message to send.'),
      '#default_value' => $this->configuration['message'],
      '#weight' => -10,
    ];

    return $form;
  }

  /**
   * {@inheritDoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state): void {
    $this->configuration['room'] = $form_state->getValue('room');
    $this->configuration['message'] = $form_state->getValue('message');
    parent::submitConfigurationForm($form, $form_state);
  }
}
